@@ -28,7 +28,7 @@ cleanup_fn rm -f $output
 $VG nbddump --long-options > $output
 if [ $? != 0 ]; then
     echo "$0: unexpected exit status"
-    fail=1
+    exit 1
 fi
 cat $output
 grep -- --length $output
