@@ -28,9 +28,9 @@ requires_linux_kernel_version 5.14
 
 requires_fuse
 requires fallocate --version
-requires dd --version
-requires nbdkit --version
-requires nbdkit sh --version
+requires $DD --version
+requires $NBDKIT --version
+requires $NBDKIT sh --version
 
 # Difficult to arrange for this test to be run this test under
 # valgrind, so don't bother.
@@ -47,10 +47,10 @@ cleanup_fn rm -rf $mp $pidfile $out
 
 mkdir $mp
 
-export mp pidfile out prog="$0"
-nbdkit -U - \
-       sh - \
-       --run '
+export DD mp pidfile out prog="$0"
+$NBDKIT -U - \
+        sh - \
+        --run '
 set -x
 
 # Run nbdfuse and connect to the nbdkit server.
@@ -71,7 +71,7 @@ fi
 ls -al $mp
 
 # Fully allocate the disk.
-dd if=/dev/zero of=$mp/nbd bs=512 count=2
+$DD if=/dev/zero of=$mp/nbd bs=512 count=2
 
 # Explicitly zero the second sector.
 fallocate -z -l 512 -o 512 $mp/nbd
