@@ -407,8 +407,7 @@ let print_binding (name, { args; optargs; ret; shortdesc }) =
 let generate_golang_bindings_go () =
   generate_header CStyle;
 
-  pr "\
-package libnbd
+  pr {|package libnbd
 
 /*
 #cgo pkg-config: libnbd
@@ -418,21 +417,21 @@ package libnbd
 #include <stdlib.h>
 #include <string.h>
 
-#include \"libnbd.h\"
-#include \"wrappers.h\"
+#include "libnbd.h"
+#include "wrappers.h"
 
 // There must be no blank line between end comment and import!
 // https://github.com/golang/go/issues/9733
 */
-import \"C\"
+import "C"
 
 import (
-    \"runtime\"
-    \"unsafe\"
+    "runtime"
+    "unsafe"
 )
 
 /* Enums. */
-";
+|};
   List.iter (
     fun { enum_prefix; enums } ->
       pr "type %s int\n" (camel_case enum_prefix);
@@ -498,8 +497,7 @@ const (
 let generate_golang_closures_go () =
   generate_header CStyle;
 
-  pr "\
-package libnbd
+  pr {|package libnbd
 
 /*
 #cgo pkg-config: libnbd
@@ -507,12 +505,12 @@ package libnbd
 
 #include <stdlib.h>
 
-#include \"libnbd.h\"
-#include \"wrappers.h\"
+#include "libnbd.h"
+#include "wrappers.h"
 */
-import \"C\"
+import "C"
 
-import \"unsafe\"
+import "unsafe"
 
 /* Closures. */
 
@@ -534,7 +532,7 @@ func copy_extent_array(entries *C.nbd_extent, count C.size_t) []LibnbdExtent {
     }
     return ret
 }
-";
+|};
 
   List.iter (
     fun { cbname; cbargs } ->
@@ -654,8 +652,7 @@ func copy_extent_array(entries *C.nbd_extent, count C.size_t) []LibnbdExtent {
 let generate_golang_wrappers_go () =
   generate_header CStyle;
 
-  pr "\
-package libnbd
+  pr {|package libnbd
 
 /*
 #cgo pkg-config: libnbd
@@ -665,10 +662,10 @@ package libnbd
 #include <stdlib.h>
 #include <string.h>
 
-#include \"libnbd.h\"
-#include \"wrappers.h\"
+#include "libnbd.h"
+#include "wrappers.h"
 
-";
+|};
 
   (* Wrappers. *)
   List.iter print_wrapper handle_calls;
@@ -676,18 +673,16 @@ package libnbd
   (* Callback wrappers. *)
   List.iter print_callback_wrapper all_closures;
 
-  pr "\
-// There must be no blank line between end comment and import!
+  pr {|// There must be no blank line between end comment and import!
 // https://github.com/golang/go/issues/9733
 */
-import \"C\"
-"
+import "C"
+|}
 
 let generate_golang_wrappers_h () =
   generate_header CStyle;
 
-  pr "\
-#ifndef LIBNBD_GOLANG_WRAPPERS_H
+  pr {|#ifndef LIBNBD_GOLANG_WRAPPERS_H
 #define LIBNBD_GOLANG_WRAPPERS_H
 
 #include <stdio.h>
@@ -695,7 +690,7 @@ let generate_golang_wrappers_h () =
 #include <assert.h>
 #include <errno.h>
 
-#include \"libnbd.h\"
+#include "libnbd.h"
 
 /* When calling callbacks we pass the callback ID (a golang int /
  * C.long) in the void *user_data field.  We need to create a block
@@ -738,13 +733,13 @@ free_error (struct error *err)
 static inline void
 missing_function (struct error *err, const char *fn)
 {
-  asprintf (&err->error, \"%%s: \"
-            \"function missing because golang bindings were compiled \"
-            \"against an old version of the C library\", fn);
+  asprintf (&err->error, "%%s: "
+            "function missing because golang bindings were compiled "
+            "against an old version of the C library", fn);
   err->errnum = ENOTSUP;
 }
 
-";
+|};
 
   (* Function decl for each wrapper. *)
   List.iter (
