@@ -128,8 +128,7 @@ let num_params args optargs =
 let generate_ocaml_nbd_mli () =
   generate_header OCamlStyle;
 
-  pr "\
-(** OCaml bindings for libnbd.
+  pr {|(** OCaml bindings for libnbd.
 
     For full documentation see libnbd-ocaml(3) and libnbd(3).
 
@@ -152,7 +151,7 @@ type cookie = int64
 type extent = int64 * int64
 (** Length and flags of an extent in {!block_status_64} callback. *)
 
-";
+|};
 
   List.iter (
     fun { enum_prefix; enums } ->
@@ -196,8 +195,7 @@ type extent = int64 * int64
   ) metadata_namespaces;
   pr "\n";
 
-  pr "\
-module Buffer : sig
+  pr {|module Buffer : sig
   type t =
     (char, Bigarray.int8_unsigned_elt, Bigarray.c_layout) Bigarray.Array1.t
   (** A buffer that persists across calls, used in {!aio_pread},
@@ -258,10 +256,10 @@ val errno_of_unix_error : Unix.error -> int
     can be used in callbacks to update the [int ref] parameter. *)
 
 type t
-(** The handle. *)
+(** The libnbd handle, equivalent to the C type [struct nbd_handle *]. *)
 
 val create : unit -> t
-(** Create a new handle. *)
+(** Create a new libnbd handle. *)
 
 val close : t -> unit
 (** Close a handle.
@@ -283,7 +281,7 @@ val with_handle : (t -> 'a) -> 'a
     subprocess is always killed; or if you need to disconnect from the
     server before continuing with another operation. *)
 
-";
+|};
 
   List.iter (
     fun (name, { args; optargs; ret; shortdesc; longdesc }) ->
@@ -305,18 +303,17 @@ val with_handle : (t -> 'a) -> 'a
 let generate_ocaml_nbd_ml () =
   generate_header OCamlStyle;
 
-  pr "\
-exception Error of string * Unix.error option
+  pr {|exception Error of string * Unix.error option
 exception Closed of string
 type cookie = int64
 type extent = int64 * int64
 
 (* Give the exceptions names so that they can be raised from the C code. *)
 let () =
-  Callback.register_exception \"nbd_internal_ocaml_error\" (Error (\"\", None));
-  Callback.register_exception \"nbd_internal_ocaml_closed\" (Closed \"\")
+  Callback.register_exception "nbd_internal_ocaml_error" (Error ("", None));
+  Callback.register_exception "nbd_internal_ocaml_closed" (Closed "")
 
-";
+|};
 
   List.iter (
     fun { enum_prefix; enums } ->
@@ -365,8 +362,7 @@ let () =
   ) metadata_namespaces;
   pr "\n";
 
-  pr "\
-module Buffer = struct
+  pr {|module Buffer = struct
   type t =
     (char, Bigarray.int8_unsigned_elt, Bigarray.c_layout) Bigarray.Array1.t
 
@@ -374,12 +370,12 @@ module Buffer = struct
     Bigarray.Array1.create Bigarray.Char Bigarray.c_layout
   let size = Bigarray.Array1.dim
 
-  external to_bytes : t -> bytes = \"nbd_internal_ocaml_buffer_to_bytes\"
-  external to_string : t -> string = \"nbd_internal_ocaml_buffer_to_bytes\"
+  external to_bytes : t -> bytes = "nbd_internal_ocaml_buffer_to_bytes"
+  external to_string : t -> string = "nbd_internal_ocaml_buffer_to_bytes"
   external _of_bytes : bytes -> t -> unit =
-    \"nbd_internal_ocaml_buffer_of_bytes\"
+    "nbd_internal_ocaml_buffer_of_bytes"
   external _of_string : string -> t -> unit =
-    \"nbd_internal_ocaml_buffer_of_bytes\"
+    "nbd_internal_ocaml_buffer_of_bytes"
   let of_bytes b =
     let buf = alloc (Bytes.length b) in
     _of_bytes b buf;
@@ -390,16 +386,16 @@ module Buffer = struct
     buf
 
   external is_zero : ?sub:(int * int) -> t -> bool =
-    \"nbd_internal_ocaml_is_zero\" [@@noalloc]
+    "nbd_internal_ocaml_is_zero" [@@noalloc]
 end
 
 external errno_of_unix_error : Unix.error -> int =
-    \"nbd_internal_code_of_unix_error\" [@@noalloc]
+    "nbd_internal_code_of_unix_error" [@@noalloc]
 
 type t
 
-external _create : unit -> t = \"nbd_internal_ocaml_nbd_create\"
-external close : t -> unit = \"nbd_internal_ocaml_nbd_close\"
+external _create : unit -> t = "nbd_internal_ocaml_nbd_create"
+external close : t -> unit = "nbd_internal_ocaml_nbd_close"
 
 let create () =
   let nbd = _create () in
@@ -410,7 +406,7 @@ let with_handle f =
   let nbd = create () in
   try let r = f nbd in close nbd; r with exn -> close nbd; raise exn
 
-";
+|};
 
   List.iter (
     fun (name, { args; optargs; ret }) ->
