@@ -590,6 +590,10 @@ and replace_pod_expr name s =
           else if string_starts_with ~prefix:"http://" content ||
                     string_starts_with ~prefix:"https://" content then
             sprintf "[%s](%s)" content content
+          else if String.contains content '|' then (
+            let text, link = split "|" content in
+            sprintf "[%s](%s)" text link
+          )
           else (* external manual page - how to link XXX *)
             sprintf "<i>%s</i>" content
        | _ ->
