@@ -58,7 +58,7 @@ let find_state path =
   with Not_found ->
        failwithf "find_state: ‘%s’ not found" (String.concat "." path)
 
-let dot_rex = Str.regexp "\\."
+let dot_rex = Str.regexp {|\.|}
 
 (* Resolve a stringified path to a state.
  *
@@ -162,7 +162,7 @@ let state_machine_prologue =
 
     let statecodes = ref [] in
     let curr_state = ref None in
-    let rex = Str.regexp "^ \\([A-Z0-9][A-Z0-9_\\.]*\\):$" in
+    let rex = Str.regexp {|^ \([A-Z0-9][A-Z0-9_\.]*\):$|} in
     List.iter (
       fun (loc, line) ->
         if Str.string_match rex line 0 then ( (* new case *)
@@ -221,7 +221,7 @@ let state_machine_prologue =
   (* Parse the state code fragments to get internal state
    * transitions, marked by "%STATE".
    *)
-  let rex = Str.regexp "%\\([\\^\\.]*[A-Z0-9][A-Z0-9_\\.]*\\)" in
+  let rex = Str.regexp {|%\([\^\.]*[A-Z0-9][A-Z0-9_\.]*\)|} in
   List.iter (
     fun (state, code, loc) ->
       let code = Str.full_split rex code in
