@@ -16,18 +16,19 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-# Test that nbdinfo --version looks sane.
+# Test that --version looks sane.
 
-fail=0
-output=$($VG nbdinfo --version)
-if [ $? != 0 ]; then
-    echo "$0: unexpected exit status"
-    fail=1
-fi
-if [ "$output" != "nbdinfo $EXPECTED_VERSION
-libnbd $EXPECTED_VERSION" ]; then
-    echo "$0: unexpected output"
-    fail=1
-fi
-echo "$output"
-exit $fail
+. ../tests/functions.sh
+set -e
+set -x
+
+tool=nbdinfo
+
+output=test-$tool.out
+cleanup_fn rm -f $output
+
+$VG $tool --version > $output
+cat $output
+
+grep "$tool $EXPECTED_VERSION" $output
+grep "libnbd $EXPECTED_VERSION" $output
