@@ -239,7 +239,9 @@ nbd_internal_command_common (struct nbd_handle *h,
     }
 
     if (h->block_minimum && (h->strict & LIBNBD_STRICT_ALIGN) &&
-        (offset | count) & (h->block_minimum - 1)) {
+        ((offset + count != h->exportsize &&
+          (count & (h->block_minimum - 1))) ||
+         (offset & (h->block_minimum - 1)))) {
       set_error (EINVAL, "request is unaligned");
       goto err;
     }
