@@ -17,11 +17,13 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *)
 
+open Ocaml_test_config
+
 let () =
   NBD.with_handle (
     fun nbd ->
       NBD.connect_command nbd
-                          ["nbdkit"; "-s"; "--exit-with-parent"; "-v";
+                          [nbdkit; "-s"; "--exit-with-parent"; "-v";
                            "null"]
   )
 
