@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # nbd client library in userspace
-# Copyright (C) 2020 Red Hat Inc.
+# Copyright Red Hat
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -25,4 +25,4 @@ requires flake8 --version
 
 d="$abs_top_srcdir"/python
 test -f "$d"/nbd.py
-flake8 "$d"/nbd.py "$d"/nbdsh.py "$d"/t/*.py
+flake8 "$d"/nbd.py "$d"/nbdsh.py "$d"/examples/*.py "$d"/t/*.py
