@@ -26,6 +26,11 @@ set -x
 # requires a particular kernel module to be loaded.
 requires_linux_kernel_version 5.6
 requires_vsock_support
+
+# We need nbdinfo and URI support.
+requires nbdinfo --version
+requires_uri
+
 requires $CUT --version
 
 # This test requires nbdkit >= 1.16 which added the --vsock option.
@@ -35,9 +40,6 @@ requires test $minor -ge 16
 
 requires $NBDKIT pattern --version
 
-# Check we built nbdinfo (this implicitly checks we have libxml2).
-requires nbdinfo --version
-
 # Because vsock ports are 32 bits, we can basically pick one at random
 # and be sure that it's not used.  However we must pick one >= 1024
 # because the ports below this are privileged.
